# Berroutils

**Python utilities**

-----

*ListOfDictContainer*

Abstract Base Class to store content as list of dictionaries

Initiate it by passing a FileHandler

```python
from berroutils.container.list_of_dict_container import ListOfDictContainer
```

*FileHandler*

The type of
- JsonFileHandler
- PickleFileHandler

```python
from berroutils.plugins.file_handler import JsonFileHandler
```
